@@ -1,7 +1,7 @@
 /* 
  gaiaexif.h -- Gaia common EXIF Metadata reading functions
   
- version 4.0, 2012 August 6
+ version 4.2, 2014 July 25
 
  Author: Sandro Furieri a.furieri@lqt.it
 
@@ -23,7 +23,7 @@ The Original Code is the SpatiaLite library
 
 The Initial Developer of the Original Code is Alessandro Furieri
  
-Portions created by the Initial Developer are Copyright (C) 2008-2012
+Portions created by the Initial Developer are Copyright (C) 2008-2013
 the Initial Developer. All Rights Reserved.
 
 Contributor(s):
@@ -89,6 +89,10 @@ extern "C"
 #define GAIA_TIFF_BLOB		9
 /** this BLOB does actually contain a WebP image */
 #define GAIA_WEBP_BLOB		10
+/** this BLOB does actually contain a SpatiaLite XmlBLOB */
+#define GAIA_XML_BLOB		11
+/** this BLOB does actually contain a GPKG Geometry */
+#define GAIA_GPB_BLOB		12
 
 /* constants used for EXIF value types */
 /** unrecognized EXIF value */
@@ -606,7 +610,8 @@ extern "C"
 
  \return the BLOB type: one of GAIA_HEX_BLOB, GAIA_GIF_BLOB, GAIA_PNG_BLOB,
  GAIA_JPEG_BLOB, GAIA_EXIF_BLOB, GAIA_EXIF_GPS_BLOB, GAIA_ZIP_BLOB,
- GAIA_PDF_BLOB, GAIA_GEOMETRY_BLOB, GAIA_TIFF_BLOB
+ GAIA_PDF_BLOB, GAIA_GEOMETRY_BLOB, GAIA_TIFF_BLOB, GAIA_WEBP_BLOB,
+ GAIA_XML_BLOB, GAIA_GPB_BLOB
  */
     GAIAEXIF_DECLARE int gaiaGuessBlobType (const unsigned char *blob,
 					    int size);
